.. autokitteh documentation master file, created by
   sphinx-quickstart on Wed Jul  3 11:27:22 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

AutoKitteh Python SDK Documentation
===================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:


Module contents
---------------

.. automodule:: autokitteh
   :members:
   :undoc-members:
   :show-inheritance:



Submodules
----------

autokitteh.asana module
-----------------------

.. automodule:: autokitteh.asana
   :members:
   :undoc-members:
   :show-inheritance:

autokitteh.atlassian module
---------------------------

.. automodule:: autokitteh.atlassian
   :members:
   :undoc-members:
   :show-inheritance:

autokitteh.attr\_dict module
----------------------------

.. automodule:: autokitteh.attr_dict
   :members:
   :undoc-members:
   :show-inheritance:

autokitteh.aws module
---------------------

.. automodule:: autokitteh.aws
   :members:
   :undoc-members:
   :show-inheritance:

autokitteh.connections module
-----------------------------

.. automodule:: autokitteh.connections
   :members:
   :undoc-members:
   :show-inheritance:

autokitteh.decorators module
----------------------------

.. automodule:: autokitteh.decorators
   :members:
   :undoc-members:
   :show-inheritance:

autokitteh.discord module
----------------------------

.. automodule:: autokitteh.discord
   :members:
   :undoc-members:
   :show-inheritance:

autokitteh.errors module
------------------------

.. automodule:: autokitteh.errors
   :members:
   :undoc-members:
   :show-inheritance:

autokitteh.events module
------------------------

.. automodule:: autokitteh.events
   :members:
   :undoc-members:
   :show-inheritance:

autokitteh.github module
------------------------

.. automodule:: autokitteh.github
   :members:
   :undoc-members:
   :show-inheritance:

autokitteh.google module
------------------------

.. automodule:: autokitteh.google
   :members:
   :undoc-members:
   :show-inheritance:

autokitteh.hubspot module
-------------------------

.. automodule:: autokitteh.hubspot
   :members:
   :undoc-members:
   :show-inheritance:

autokitteh.openai module
------------------------

.. automodule:: autokitteh.openai
   :members:
   :undoc-members:
   :show-inheritance:

autokitteh.packages module
--------------------------

.. automodule:: autokitteh.packages
   :members:
   :undoc-members:
   :show-inheritance:


autokitteh.slack module
-----------------------

.. automodule:: autokitteh.slack
   :members:
   :undoc-members:
   :show-inheritance:

autokitteh.twilio module
------------------------

.. automodule:: autokitteh.twilio
   :members:
   :undoc-members:
   :show-inheritance:

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
